"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.invoke = void 0;
process.env.FORCE_COLOR = "0";
const nanolru_1 = __importDefault(require("nanolru"));
const path_1 = __importDefault(require("path"));
const prettier_1 = __importDefault(require("prettier"));
const prettier_2 = require("prettier");
const configCache = new nanolru_1.default({ max: 20, maxAge: 60000 });
const getParserName = (ext) => {
    switch (ext) {
        case ".tsx":
        case ".ts":
            return "typescript";
        case ".css":
        case ".scss":
            return "css";
        case ".html":
            return "html";
        case ".json":
            return "json";
        case ".yml":
        case ".yaml":
            return "yaml";
        case ".md":
        case ".markdown":
        case ".mkd":
            return "markdown";
        default:
            return "babel";
    }
};
const withParser = (options, filePath) => {
    return {
        ...options,
        parser: getParserName(path_1.default.extname(filePath)),
    };
};
const resolveConfig = (cwd, filePath) => {
    let v = configCache.get(cwd);
    if (!v) {
        v = prettier_1.default.resolveConfig.sync(filePath, {
            editorconfig: true,
            useCache: false,
        });
        if (v) {
            configCache.set(cwd, v);
        }
    }
    return withParser(v, filePath);
};
const resolveFile = (cwd, fileName) => {
    if (path_1.default.isAbsolute(fileName)) {
        return [fileName, fileName];
    }
    return [cwd, path_1.default.join(cwd, fileName)];
};
function invoke(cwd, args, text, _mtime) {
    const fileName = args[0];
    const [cacheKey, fullPath] = resolveFile(cwd, fileName);
    const options = resolveConfig(cacheKey, fullPath);
    return prettier_2.format(text, options);
}
exports.invoke = invoke;
